# distribution_playground




# Reference
- [Probability Playground - Buffalo](https://www.acsu.buffalo.edu/~adamcunn/probability/normal.html)
- [DDPM - dataflowr](https://github.com/dataflowr/notebooks/tree/master/Module18)